window.h
changeset 5667 248a3234d2e2
parent 5666 1af12f02bf17
child 5669 ea25407ffa55
--- a/window.h	Fri Dec 29 17:07:41 2006 +0000
+++ b/window.h	Fri Dec 29 17:16:12 2006 +0000
@@ -264,13 +264,14 @@
 } WindowDesc;
 
 enum WindowDefaultFlag {
-	WDF_STD_TOOLTIPS    =  1, /* use standard routine when displaying tooltips */
-	WDF_DEF_WIDGET      =  2, /* default widget control for some widgets in the on click event */
-	WDF_STD_BTN         =  4, /* default handling for close and drag widgets (widget no 0 and 1) */
+	WDF_STD_TOOLTIPS    =   1, /* use standard routine when displaying tooltips */
+	WDF_DEF_WIDGET      =   2, /* default widget control for some widgets in the on click event */
+	WDF_STD_BTN         =   4, /* default handling for close and drag widgets (widget no 0 and 1) */
 
-	WDF_UNCLICK_BUTTONS = 16, /* Unclick buttons when the window event times out */
-	WDF_STICKY_BUTTON   = 32, /* Set window to sticky mode; they are not closed unless closed with 'X' (widget 2) */
-	WDF_RESIZABLE       = 64, /* A window can be resized */
+	WDF_UNCLICK_BUTTONS =  16, /* Unclick buttons when the window event times out */
+	WDF_STICKY_BUTTON   =  32, /* Set window to sticky mode; they are not closed unless closed with 'X' (widget 2) */
+	WDF_RESIZABLE       =  64, /* A window can be resized */
+	WDF_MODAL           = 128, /* The window is a modal child of some other window, meaning the parent is 'inactive' */
 };
 
 /* can be used as x or y coordinates to cause a specific placement */
@@ -598,7 +599,7 @@
 	WF_DISABLE_VP_SCROLL = 1 << 10,
 
 	WF_WHITE_BORDER_ONE  = 1 << 11,
-	WF_WHITE_BORDER_MASK = 3 << 11,
+	WF_WHITE_BORDER_MASK = 1 << 12 | WF_WHITE_BORDER_ONE,
 	WF_SCROLL2           = 1 << 13,
 };